# This file will be patched by setup.py
# The __version__ should be set to the branch name
# (e.g. "develop" or "1.2.x")

# You MUST use double quotes (so " and not ')

__version__ = "1.2.1"
__baseline__ = "d32cf57c7573ed43bcab40eb9b23a0853f1f7015"
